/*
 * _____________________________________________________________________________
 * 
 * INAF - OATS National Institute for Astrophysics - Astronomical Observatory of
 * Trieste INAF - IA2 Italian Center for Astronomical Archives
 * _____________________________________________________________________________
 * 
 * Copyright (C) 2017 Istituto Nazionale di Astrofisica
 * 
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License Version 3 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
package it.inaf.ia2.tsm.xmlmodel;

import java.io.Serializable;

/**
 *
 * @author Sonia Zorba {@literal <zorba at oats.inaf.it>}
 */
public class PropertyModel implements Serializable {

    private static final long serialVersionUID = -3081516272534689428L;

    private String name;
    private Class type;
    private Integer size;
    private boolean updatable;
    private boolean nullable;
    private String loaderKey;

    private PropertyModel() {
    }

    public PropertyModel(PropertyXMLModel propertyXMLModel) {
        try {
            name = propertyXMLModel.getName();
            type = Class.forName(propertyXMLModel.getType());
            size = propertyXMLModel.getSize();
            updatable = propertyXMLModel.isUpdatable();
            nullable = propertyXMLModel.isNullable();
            loaderKey = propertyXMLModel.getLoaderKey();
        } catch (ClassNotFoundException e) {
            throw new ExceptionInInitializerError(
                    "Invalid property type for property " + propertyXMLModel.getName()
                    + ". ClassNotFoundException: " + propertyXMLModel.getType());
        }
    }

    public String getName() {
        return name;
    }

    public Class getType() {
        return type;
    }

    public Integer getSize() {
        return size;
    }

    public boolean isUpdatable() {
        return updatable;
    }

    public boolean isNullable() {
        return nullable;
    }

    public String getLoaderKey() {
        return loaderKey;
    }
}
